package xyz.leomurca.csgomatches.ui.screens.matchdetails

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.requiredWidthIn
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.hilt.navigation.compose.hiltViewModel
import coil3.compose.AsyncImage
import xyz.leomurca.csgomatches.R
import xyz.leomurca.csgomatches.domain.model.MatchStatus
import xyz.leomurca.csgomatches.domain.model.Team
import xyz.leomurca.csgomatches.ui.components.LoadingIndicator
import xyz.leomurca.csgomatches.ui.navigation.MatchDetailsRoute
import xyz.leomurca.csgomatches.ui.theme.LiveRed
import xyz.leomurca.csgomatches.ui.theme.White
import xyz.leomurca.csgomatches.ui.theme.White_50

@Composable
fun MatchDetailsScreen(
    viewModel: MatchDetailsViewModel = hiltViewModel(),
    matchDetails: MatchDetailsRoute,
    onBackClick: () -> Unit
) {
    val uiState = viewModel.uiState.collectAsState()

    LaunchedEffect(Unit) {
        if (matchDetails.leftOpponentId != -1L) {
            viewModel.loadTeam(matchDetails.leftOpponentId.toString(), isLeft = true)
        } else {
            viewModel.updateTeamToDefault(isLeft = true)
        }
        if (matchDetails.rightOpponentId != -1L) {
            viewModel.loadTeam(matchDetails.rightOpponentId.toString(), isLeft = false)
        } else {
            viewModel.updateTeamToDefault(isLeft = false)
        }
    }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .background(MaterialTheme.colorScheme.background),
    ) {
        TopBar(matchDetails.leagueAndSerieName, onBackClick)

        val value = uiState.value
        when {
            value.errorMessage != null -> Text(value.errorMessage)
            value.isLoading -> LoadingIndicator()
            value.leftTeam != null && value.rightTeam != null -> Column {
                MatchupRow(leftTeam = value.leftTeam, rightTeam = value.rightTeam)
                ScheduleRow(matchDetails.scheduleString, matchDetails.status)
            }
        }
    }
}

@Composable
fun ScheduleRow(scheduleString: String, matchStatus: MatchStatus) {
    val modifier = if (matchStatus == MatchStatus.LIVE)
        Modifier
            .background(LiveRed, RoundedCornerShape(16.dp))
            .padding(horizontal = 12.dp, vertical = 8.dp)
    else Modifier
    Row(
        Modifier
            .fillMaxWidth()
            .padding(top = 20.dp), horizontalArrangement = Arrangement.Center
    ) {
        Text(
            scheduleString,
            style = MaterialTheme.typography.headlineMedium,
            color = White,
            modifier = modifier
        )
    }
}

@Composable
private fun MatchupRow(leftTeam: Team, rightTeam: Team) {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .padding(top = 24.dp, bottom = 20.dp),
        horizontalArrangement = Arrangement.Center,
        verticalAlignment = Alignment.CenterVertically
    ) {
        Column(horizontalAlignment = Alignment.CenterHorizontally) {
            AsyncImage(
                model = leftTeam.imageUrl,
                contentDescription = "${leftTeam.name} logo",
                error = painterResource(R.drawable.fallback_image_round),
                placeholder = painterResource(R.drawable.fallback_image_round),
                modifier = Modifier.size(60.dp),
                contentScale = ContentScale.Fit
            )
            Text(
                leftTeam.name ?: "A ser definido",
                style = MaterialTheme.typography.labelMedium,
                color = White,
                textAlign = TextAlign.Center,
                modifier = Modifier
                    .padding(top = 10.dp)
                    .requiredWidthIn(max = 60.dp)
            )
        }
        Text(
            "vs",
            style = MaterialTheme.typography.bodyMedium,
            color = White_50,
            modifier = Modifier.padding(horizontal = 20.dp)
        )

        Column(horizontalAlignment = Alignment.CenterHorizontally) {
            AsyncImage(
                model = rightTeam.imageUrl,
                contentDescription = "${rightTeam.name} logo",
                error = painterResource(R.drawable.fallback_image_round),
                placeholder = painterResource(R.drawable.fallback_image_round),
                modifier = Modifier.size(60.dp),
                contentScale = ContentScale.Fit
            )
            Text(
                rightTeam.name ?: "A ser definido",
                style = MaterialTheme.typography.labelMedium,
                color = White,
                textAlign = TextAlign.Center,
                modifier = Modifier
                    .padding(top = 10.dp)
                    .requiredWidthIn(max = 60.dp)
            )
        }
    }
}

@Composable
private fun TopBar(leagueAndSerieName: String, onBackClick: () -> Unit) {
    Row(
        Modifier
            .fillMaxWidth()
            .background(MaterialTheme.colorScheme.background)
            .padding(top = 52.dp, start = 24.dp, end = 24.dp),
        verticalAlignment = Alignment.CenterVertically,
    ) {
        IconButton(onBackClick, modifier = Modifier) {
            Icon(Icons.AutoMirrored.Default.ArrowBack, contentDescription = "", tint = White)
        }

        Text(
            leagueAndSerieName,
            textAlign = TextAlign.Center,
            style = MaterialTheme.typography.titleMedium,
            color = White,
        )
    }
}
